"""In Memory File manager."""

import tempfile
from pathlib import Path
from typing import Any, Dict, List

import boto3
from numerous.files.file_manager import FileManager as FileManagerInterface
from numerous.files.file_manager import StrOrPath


class Open:
    def __init__(
        self,
        file_manager: Any, # noqa: ANN401
        filename: str,
        mode: str = "r",
    ) -> None:
        self.file_manager = file_manager
        self.filename = filename
        self.mode = mode
        self.file = None
        self.file_path: None|Path = None

    def __enter__(self): # type: ignore[no-untyped-def] # noqa: ANN204
        """Open the file and return the file object."""
        tempfile_ = tempfile.NamedTemporaryFile(delete=False)
        self.file_path = Path(tempfile_.name)
        tempfile_.close()

        if self.file_manager.exists(self.filename):
            self.file_manager.get(self.filename, self.file_path)
        elif "w" in self.mode:
            Path.touch(self.file_path)
        elif "r" in self.mode:
            err_msg = f"File {self.filename} does not exist."
            raise FileNotFoundError(err_msg)

        self.file = Path.open(self.file_path, self.mode) # type: ignore[assignment]
        return self.file

    def __exit__(self, *args: object) -> None:
        """Close the file and save it if needed."""
        if self.file:
            self.file.close()
            # Assuming the operations that modify the file are done,
            # we save it when closing
            if "w" in self.mode or "a" in self.mode:
                self.file_manager.put(self.file.name, self.filename)
            # Delete the temporary file.
            Path.unlink(self.file.name)


class FileManager(FileManagerInterface):

    """
    AWS S3 Bucket File manager.

    This class provides an AWS S3 implementation of the FileManagerInterface,
    the files handled by this class are stored in an AWS S3 bucket.

    Set the env variable `NUMEROUS_FILES_BACKEND` to `AWS_S3`
    to get an instance of this class when using the file_manager_factory method.

    To save files on AWS S3 a bucket and a base prefix is needed to be specified
    using the env variables `NUMEROUS_FILES_BUCKET` and `NUMEROUS_FILES_BASE_PREFIX`.

    In order for the file_manager to access your files on aws,
    you need to provide authentication to access AWS.

    If you set the env variables `NUMEROUS_FILES_AWS_ACCESS_KEY`
    and `NUMEROUS_FILES_AWS_SECRET_KEY` with your aws credentials
    they will be used for  authenticatication.

    In case these env variables are not set the client will
    authenticate with the AWS credentials from your environment.

    If needed you can supply the names of the env variables you use to store
    information of the bucket, base_prefix, aws_access and aws_secrets to
    the file_manager_factory method as the following key word arguments:
    bucket, base_prfix, aws_access_key_id, and aws_secret_access_key.

    """

    def __init__(
        self, bucket: str, base_prefix: str, credentials: Dict[str, Any] | None = None,
    ) -> None:
        self._bucket = bucket
        self._base_prefix = base_prefix

        if credentials is not None:
            self._client = boto3.client("s3", **credentials)
        else:
            # Use the default session.
            self._client = boto3.client("s3")

    def _wrap_path(self, path: str) -> str:
        if self._base_prefix == "":
            return path
        return f"{self._base_prefix}/{path}"

    def _unwrap_path(self, path: str) -> str:
        if self._base_prefix == "":
            return path
        return path.replace(f"{self._base_prefix}/", "", 1)


    def put(self, src: StrOrPath, dst: str) -> None:
        """
        Upload a file to a path.

        Args:
            src: Source path.
            dst: Destination path.

        """
        self._client.upload_file(str(src), self._bucket, self._wrap_path(dst))

    def remove(self, path: str) -> None:
        """
        Remove a file at a path.

        Args:
            path: Path to file.

        """
        self._client.delete_object(
            Bucket=self._bucket, Key=self._wrap_path(path),
        )

    def list(self, path: str | None = None) -> List[str]:
        """
        List files at a path.

        Args:
            path: Path to list files at.

        """
        if path is None:
            path = self._base_prefix

        query_result = self._client.list_objects(
            Bucket=self._bucket, Prefix=self._wrap_path(path),
        )
        if "Contents" not in query_result:
            return []
        list_results = [obj["Key"] for obj in query_result["Contents"]]

        # Remove the base prefix from the results. But only first occurence.
        return [
            self._unwrap_path(result) for result in list_results
        ]

    def exists(self, path: str) -> bool:
        """
        Check if a file exists at a path.

        Args:
            path: Path to file.

        Returns:
            True if the file exists, False otherwise.

        """
        query_result = self._client.list_objects(
            Bucket=self._bucket, Prefix=self._wrap_path(path),
        )

        return "Contents" in query_result

    def move(self, src: str, dst: str) -> None:
        """
        Move a file from a source to a destination.

        Args:
            src: Source path.
            dst: Destination path.

        """
        self._client.copy_object(
            Bucket=self._bucket,
            CopySource=f"{self._bucket}/"+self._wrap_path(src),
            Key=self._wrap_path(dst),
        )
        self._client.delete_object(
            Bucket=self._bucket, Key=self._wrap_path(src),
        )

    def copy(self, src: str, dst: str) -> None:
        """
        Copy a file from a source to a destination.

        Args:
            src: Source path.
            dst: Destination path.

        """
        self._client.copy_object(
            Bucket=self._bucket,
            CopySource=f"{self._bucket}/"+self._wrap_path(src),
            Key=f"{self._base_prefix}/{dst}",
        )

    def get(self, src: str, dest: StrOrPath) -> None:
        """
        Download a file from a source to a destination.

        Args:
            src: Source path.
            dest: Destination path.

        """
        self._client.download_file(
            self._bucket,
            self._wrap_path(src),
            str(dest),
        )

    def open(self, path: str, mode: str = "r") -> Open:
        """
        Open a file at a path.

        Args:
            path: Path to file.
            mode: Mode to open file in.

        Returns:
            File content.

        """
        return Open(self, path, mode)


if __name__ == "__main__":
    list_files = FileManager("numerous-files", "tests").list()



import os

import pytest
from numerous.files import file_manager_factory
from numerous.files.aws_s3 import FileManager as AwsS3
from numerous.files.memory import FileManager as Memory


def test_file_manager_factory_default() -> None:
    file_manager = file_manager_factory()
    assert file_manager is not None
    assert isinstance(file_manager, Memory)


def test_file_manager_factory_memory() -> None:
    os.environ["NUMEROUS_FILES_BACKEND"] = "INMEMORY"
    file_manager = file_manager_factory()
    assert file_manager is not None
    assert isinstance(file_manager, Memory)

    # Cleanup
    del os.environ["NUMEROUS_FILES_BACKEND"]


def test_file_manager_factory_aws_s3(monkeypatch: pytest.MonkeyPatch) -> None:
    monkeypatch.setenv("NUMEROUS_FILES_BACKEND", "AWS_S3")
    monkeypatch.setenv("NUMEROUS_FILES_BUCKET", "numerous-files")
    monkeypatch.setenv("NUMEROUS_FILES_BASE_PREFIX", "tests")

    file_manager = file_manager_factory()
    assert file_manager is not None
    assert isinstance(file_manager, AwsS3)



"""Local Folder File manager."""

import shutil
from pathlib import Path
from typing import Any

from numerous.files.file_manager import FileManager as FileManagerInterface
from numerous.files.file_manager import StrOrPath


class Open:
    def __init__(self, filename: Path, mode: str = "r") -> None:
        self.filename = filename
        self.mode = mode
        self.file: None | Any = None

    def __enter__(self): # type: ignore[no-untyped-def] # noqa: ANN204
        """Open the file."""
        self.file = Path.open(self.filename, self.mode)
        return self.file

    def __exit__(self, *args: object) -> None:
        """Close the file."""
        if self.file:
            self.file.close()
            # Assuming the operations that modify the file are done,
            # we save it when closing


class FileManager(FileManagerInterface):

    """
    Local Folder File manager.

    This class provides an local folder implementation of the FileManagerInterface.

    Use this class for testing or when you want to store files in a local folder only.
    """

    def __init__(self, workfolder: StrOrPath = "./tmp") -> None:
        """
        Initialize the LocalFolderFileManager.

        Args:
            workfolder: Path to the working folder.

        """
        self._workfolder = Path(workfolder)

        # Ensure the workfolder exists.
        self._workfolder.mkdir(parents=True, exist_ok=True)

    def put(self, src: StrOrPath, dst: StrOrPath) -> None:
        """
        Upload a file to a path.

        Args:
            src: Source path.
            dst: Destination path.

        """
        _path = self._workfolder / Path(dst)
        # Ensure the parent folder exists.
        _path.parent.mkdir(parents=True, exist_ok=True)

        with Path.open(Path(src), "rb") as f:
            shutil.copyfileobj(f, Path.open(_path, "wb"))

    def remove(self, path: StrOrPath) -> None:
        """
        Remove a file at a path.

        Args:
            path: Path to file.

        """
        _path = self._workfolder / Path(path)
        Path(_path).unlink()

    def list(self, path: StrOrPath | None) -> list[str]:
        """
        List files at a path.

        Args:
            path: Path to list files at.

        """
        _path = self._workfolder if path is None else self._workfolder / Path(path)

        # Make all paths relative to the workfolder.
        return [
            str(p.relative_to(self._workfolder))
            for p in _path.rglob("*")
            if p.is_file()
        ]

    def move(self, src: StrOrPath, dst: StrOrPath) -> None:
        """
        Move a file from a source to a destination.

        Args:
            src: Source path.
            dst: Destination path.

        """
        _src = self._workfolder / Path(src)
        _dst = self._workfolder / Path(dst)
        # Ensure the parent folder exists.
        _dst.parent.mkdir(parents=True, exist_ok=True)
        shutil.move(_src, _dst)

    def copy(self, src: StrOrPath, dst: StrOrPath) -> None:
        """
        Copy a file from a source to a destination.

        Args:
            src: Source path.
            dst: Destination path.

        """
        _src = self._workfolder / Path(src)
        _dst = self._workfolder / Path(dst)
        # Ensure the parent folder exists.
        _dst.parent.mkdir(parents=True, exist_ok=True)
        shutil.copy(_src, _dst)

    def get(self, src: StrOrPath, dest: StrOrPath) -> None:
        """
        Download a file from a source to a destination.

        Args:
            src: Source path.
            dest: Destination path.

        """
        _src = self._workfolder / Path(src)
        # Ensure the parent folder exists.
        Path(dest).parent.mkdir(parents=True, exist_ok=True)
        shutil.copy(_src, dest)

    def open(self, path: StrOrPath, mode: str) -> Open: # type: ignore[override]
        """
        Open a file at a path.

        Args:
            path: Path to file.
            mode: Open mode.

        """
        if "w" in mode or "a" in mode:
            # Ensure the parent folder exists.
            Path(self._workfolder / Path(path)).parent.mkdir(
                parents=True, exist_ok=True,
            )
            # Create empty file if it does not exist.
            Path(self._workfolder / Path(path)).touch()

        return Open(self._workfolder / Path(path), mode)



"""Numerous files module."""

__version__ = "0.0.1"

import os

from numerous.files.aws_s3 import FileManager as AwsS3
from numerous.files.local import FileManager as LocalFolder
from numerous.files.memory import FileManager as Memory


def file_manager_factory(**kwargs: dict[str, str]) -> AwsS3 | Memory | LocalFolder:
    """
    Use the factory for creating a file manager.

    This is the main entry point for using the numerous files module.
    Use this method to get a file manager instance based on the value
    of the `NUMEROUS_FILES_BACKEND` environment variable.

    The file manager instance can be used to perform file management
    operations such as reading, writing, and deleting files.

    Args:
        file_manager: File manager type.
        **kwargs: Keyword arguments to pass to the file

    """
    # Get the file manager type from the environment.
    file_manager = os.environ.get("NUMEROUS_FILES_BACKEND", "INMEMORY")

    if file_manager == "INMEMORY":
        return Memory(**kwargs)

    if file_manager == "AWS_S3":
        env_var_aws_access_key = str(
            kwargs.get("aws_access_key_id", "NUMEROUS_FILES_AWS_ACCESS_KEY"),
        )
        env_var_aws_secret_key = str(
            kwargs.get("aws_secret_access_key", "NUMEROUS_FILES_AWS_SECRET_KEY"),
        )
        env_var_bucket = str(kwargs.get("bucket", "NUMEROUS_FILES_BUCKET"))
        env_var_base_prefix = str(
            kwargs.get("base_prefix", "NUMEROUS_FILES_BASE_PREFIX"),
        )

        # Get the credentials from the environment.
        if (
            env_var_aws_access_key in os.environ
            and env_var_aws_secret_key in os.environ
        ):
            credentials = {
                "aws_access_key_id": os.environ[env_var_aws_access_key],
                "aws_secret_access_key": os.environ[env_var_aws_secret_key],
            }
        else:
            credentials = None
        # If the credentials are not in the environment,
        # set them to None so the aws client will use default auth.

        # Get the bucket from the environment.
        bucket = os.getenv(env_var_bucket, "numerous-files")
        # Get the base prefix from the environment.
        base_prefix = os.environ.get(env_var_base_prefix, "")

        env_params = {
            "bucket": bucket,
            "base_prefix": base_prefix,
        }
        env_params.update(kwargs)  # type: ignore[arg-type]

        return AwsS3(
            bucket=env_params["bucket"],
            base_prefix=env_params["base_prefix"],
            credentials=credentials,
        )

    if file_manager == "LOCAL":
        # Get a temporary folder from the operating system.

        return LocalFolder(workfolder=str(kwargs.get("workfolder", "./tmp")))

    err_str = f"Unknown file manager type {file_manager}"
    raise ValueError(err_str)



from pathlib import Path
from typing import Generator

import pytest
from numerous.files.aws_s3 import FileManager


@pytest.fixture()
def test_file_create() -> Generator[Path, None, None]:
    path_to_file = Path("test.txt")

    with Path.open(path_to_file, "w") as f:
        f.write("Hello World!")
    yield path_to_file
    Path.unlink(path_to_file)


@pytest.fixture()
def file_manager() -> Generator[FileManager, None, None]:
    file_manager = FileManager(bucket="numerous-files", base_prefix="tests")
    yield file_manager

    # Cleanup
    for file in file_manager.list():
        file_manager.remove(file)


def test_file_put(test_file_create: str, file_manager: FileManager) -> None:
    file_manager.put(test_file_create, "tests/test_aws_filemanager.py")


def test_file_remove(test_file_create: str, file_manager: FileManager) -> None:
    upload_path = "tests/test.txt"

    file_manager.put(test_file_create, upload_path)
    file_manager.remove(upload_path)


def test_file_list(test_file_create: str, file_manager: FileManager) -> None:
    upload_path = "tests/test.txt"

    file_manager.put(test_file_create, upload_path)
    results = file_manager.list("tests/")

    assert upload_path in results


def test_file_move(test_file_create: str, file_manager: FileManager) -> None:
    upload_path = "tests/test.txt"

    file_manager.put(test_file_create, upload_path)
    file_manager.move(upload_path, "tests/test2.txt")

    assert "tests/test2.txt" in file_manager.list("tests/")
    assert upload_path not in file_manager.list("tests/")


def test_file_copy(test_file_create: str, file_manager: FileManager) -> None:
    upload_path = "tests/test.txt"

    file_manager.put(test_file_create, upload_path)
    file_manager.copy(upload_path, "tests/test2.txt")

    assert "tests/test2.txt" in file_manager.list("tests/")
    assert upload_path in file_manager.list("tests/")


def test_file_get(test_file_create: str, file_manager: FileManager) -> None:
    upload_path = "tests/test_aws_filemanager.py"

    file_manager.put(test_file_create, upload_path)
    file_manager.get(upload_path, "test_download.txt")

    with Path.open(Path("test_download.txt")) as f:
        assert f.read() == "Hello World!"

    Path.unlink(Path("test_download.txt"))


def test_file_open_read(file_manager: FileManager, test_file_create: str) -> None:
    upload_path = "tests/test.txt"

    file_manager.put(test_file_create, upload_path)
    with file_manager.open(upload_path, "r") as f:
        assert f.read() == "Hello World!"


def test_file_open_write(file_manager: FileManager) -> None:
    upload_path = "tests/test.txt"

    with file_manager.open(upload_path, "w") as f:
        f.write("Hello Again!")

    with file_manager.open(upload_path, "r") as f:
        assert f.read() == "Hello Again!"


def test_file_open_write_bytes(file_manager: FileManager) -> None:
    upload_path = "tests/test.txt"

    with file_manager.open(upload_path, "wb") as f:
        f.write(b"Hello Again!")

    with file_manager.open(upload_path, "rb") as f:
        assert f.read() == b"Hello Again!"



from pathlib import Path
from typing import Generator

import pytest
from numerous.files.memory import FileManager


@pytest.fixture()
def test_file_create() -> Generator[Path, None, None]:
    path_to_file = Path("test.txt")

    with Path.open(path_to_file, "w") as f:
        f.write("Hello World!")
    yield path_to_file
    Path.unlink(path_to_file)


def test_file_manager_create() -> None:
    file_manager = FileManager()  # noqa: F841


def test_file_put(test_file_create: str) -> None:
    file_manager = FileManager()

    file_manager.put(test_file_create, "tests/text.txt")


def test_file_remove(test_file_create: str) -> None:
    file_manager = FileManager()

    upload_path = "tests/text.txt"

    file_manager.put(test_file_create, upload_path)
    file_manager.remove(upload_path)


def test_file_list(test_file_create: str) -> None:
    file_manager = FileManager()

    upload_path = "tests/text.txt"

    file_manager.put(test_file_create, upload_path)
    results = file_manager.list("tests/")
    assert upload_path in results


def test_file_move(test_file_create: str) -> None:
    file_manager = FileManager()

    upload_path = "tests/text.txt"

    file_manager.put(test_file_create, upload_path)
    file_manager.move(upload_path, "tests/text2.txt")

    file_manager.list("tests/")
    assert "tests/text2.txt" in file_manager.list("tests/")
    assert upload_path not in file_manager.list("tests/")


def test_file_copy(test_file_create: str) -> None:
    file_manager = FileManager()

    upload_path = "tests/tests/text.txt"

    file_manager.put(test_file_create, upload_path)
    file_manager.copy(upload_path, "tests/text2.txt")

    file_manager.list("tests/")
    assert "tests/text2.txt" in file_manager.list("tests/")
    assert upload_path in file_manager.list("tests/")


def test_file_get(test_file_create: str) -> None:
    file_manager = FileManager()

    upload_path = "tests/text.txt"

    file_manager.put(test_file_create, upload_path)
    file_manager.get(upload_path, "text_download.txt")

    with Path.open(Path("text_download.txt")) as f:
        assert f.read() == "Hello World!"

    Path.unlink(Path("text_download.txt"))


def test_file_open_read(test_file_create: str) -> None:
    file_manager = FileManager()

    upload_path = "tests/text.txt"

    file_manager.put(test_file_create, upload_path)

    with file_manager.open(upload_path, "r") as f:
        assert f.read() == "Hello World!"


def test_file_open_write_string() -> None:
    file_manager = FileManager()

    upload_path = "tests/text.txt"

    with file_manager.open(upload_path, "w") as f:
        f.write("Hello Again!") # type: ignore[arg-type]

    with file_manager.open(upload_path) as f:
        assert f.read() == "Hello Again!"



"""In Memory File manager."""

import io
from pathlib import Path
from typing import List

from numerous.files.file_manager import FileManager as FileManagerInterface
from numerous.files.file_manager import StrOrPath


class Open:
    def __init__(self, files: dict[str, bytes], filename: str, mode: str = "r") -> None:
        self.filename = filename
        self.mode = mode

        self._files = files
        self.data: io.BytesIO | io.StringIO = io.BytesIO()

    def __enter__(self) -> io.BytesIO | io.StringIO:
        """Open the file."""
        file_content = self._files.get(self.filename, b"")

        # Make a file-like object.
        if self.mode in ("rb", "r+b", "wb", "w+b", "ab", "a+b"):
            self.data = io.BytesIO(file_content)
        elif self.mode in ("r", "r+", "w", "w+", "a", "a+"):
            self.data = io.StringIO(file_content.decode())

        return self.data

    def __exit__(self, *args: object) -> None:
        """Close the file."""
        # Store the file content back in the dictionary.
        if "w" in self.mode or "a" in self.mode:
            if "b" in self.mode:
                self._files[self.filename] = self.data.getvalue() # type: ignore[assignment]
            else:
                self._files[self.filename] = self.data.getvalue().encode() # type: ignore[union-attr]


class FileManager(FileManagerInterface):

    """
    In Memory File manager.

    This class provides an in-memory implementation of the FileManagerInterface.

    Use this class for testing or when you want to store files in memory only.
    This is the default file manager return by the file_manager_factory method.
    """

    def __init__(self) -> None:
        self._files: dict[str, bytes] = {}

    def put(self, src: StrOrPath, dst: str) -> None:
        """
        Upload a file to a path.

        Args:
            src: Source path.
            dst: Destination path.

        """
        with Path.open(Path(src), "rb") as f:
            self._files[dst] = f.read()

    def remove(self, path: str) -> None:
        """
        Remove a file at a path.

        Args:
            path: Path to file.

        """
        del self._files[path]

    def list(self, path: str | None) -> List[str]:
        """
        List files at a path.

        Args:
            path: Path to list files at.

        """
        if path is None:
            return list(self._files.keys())
        return [p for p in self._files if p.startswith(path)]

    def move(self, src: str, dst: str) -> None:
        """
        Move a file from a source to a destination.

        Args:
            src: Source path.
            dst: Destination path.

        """
        self._files[dst] = self._files[src]
        del self._files[src]

    def copy(self, src: str, dst: str) -> None:
        """
        Copy a file from a source to a destination.

        Args:
            src: Source path.
            dst: Destination path.

        """
        self._files[dst] = self._files[src]

    def get(self, src: str, dest: StrOrPath) -> None:
        """
        Download a file from a source to a destination.

        Args:
            src: Source path.
            dest: Destination path.

        """
        with Path.open(Path(dest), "wb") as f:
            f.write(self._files[src])

    def open(self, path: str, mode: str = "r") -> io.BytesIO | io.StringIO:
        """
        Open a file at a path.

        Args:
            path: Path to file.
            mode: Mode to open file in.

        Returns:
            File content.

        """
        if ("r" in mode or "a" in mode) and (path not in self._files):
            err_msg = f"File {path} not found."
            raise FileNotFoundError(err_msg)

        if ("w" in mode or "a" in mode) and (path not in self._files):

            self._files[path] = b""

        return Open(self._files, path, mode) # type: ignore[return-value]



"""Interface for file management operations."""

from abc import ABC, abstractmethod
from pathlib import Path
from typing import Any, List

StrOrPath = Path | str


class FileManager(ABC):

    """
    Abstract Interface for file management operations.

    This class provides a structured interface for handling files, including
    methods for reading, writing, and deleting files. Implementations should
    provide specific mechanisms for these operations.
    """

    @abstractmethod
    def put(self, src: StrOrPath, dst: str) -> None:
        """
        Upload a file to a path.

        Args:
            src: Source file path.
            dst: Destination file path.

        """
        ...

    @abstractmethod
    def remove(self, path: str) -> None:
        """
        Remove a file at a path.

        Args:
            path: File path to remove.

        """
        ...

    @abstractmethod
    def list(self, path: str | None) -> List[str]:
        """
        List files at a path.

        Args:
            path: Path to list files from.

        """
        ...

    @abstractmethod
    def move(self, src: str, dst: str) -> None:
        """
        Move a file from a source to a destination.

        Args:
            src: Source file path.
            dst: Destination file path.

        """
        ...

    @abstractmethod
    def copy(self, src: str, dst: str) -> None:
        """
        Copy a file from a source to a destination.

        Args:
            src: Source file path.
            dst: Destination file path.

        """
        ...

    @abstractmethod
    def get(self, src: str, dst: Path | str) -> None:
        """
        Download a file from a source to a destination.

        Args:
            src: Source file path.
            dst: Destination file path.

        """
        ...

    @abstractmethod
    def open(self, path: str, mode: str = "r") -> Any: # noqa: ANN401
        """
        Open a file at a path.

        Args:
            path: Path to file.
            mode: Mode to open file in.

        Returns:
            File content.

        """
        ...



import os
from pathlib import Path
from typing import Generator

import pytest
from numerous.files import file_manager_factory


@pytest.fixture()
def file_text() -> Generator[Path, None, None]:
    path_to_file = Path("test.txt")

    with Path.open(path_to_file, "w") as f:
        f.write("Hello World!")
    yield path_to_file

    Path.unlink(path_to_file)


def test_file_manager_create(file_text: str, monkeypatch: pytest.MonkeyPatch) -> None:
    monkeypatch.setenv("NUMEROUS_FILES_BACKEND", "AWS_S3")
    monkeypatch.setenv("NUMEROUS_FILES_BUCKET", "numerous-files-test")
    monkeypatch.setenv("NUMEROUS_FILES_BASE_PREFIX", "tests")

    print("Access key: ", os.environ["NUMEROUS_FILES_AWS_ACCESS_KEY"])  # noqa: T201

    file_manager = file_manager_factory()

    file_manager.put(file_text, "test_aws_filemanager.py")

    file_manager.remove("test_aws_filemanager.py")
